import React, { createContext, useContext, useRef, useState, useCallback, useEffect, createElement, useReducer } from 'react';

var AnimationType;
(function (AnimationType) {
    AnimationType["FADE_IN"] = "fadeIn";
    AnimationType["FADE_IN_UP"] = "fadeInUp";
    AnimationType["FLASH"] = "flash";
    AnimationType["HEART_BEAT"] = "heartBeat";
    AnimationType["SLIDE_IN_LEFT"] = "slideInLeft";
    AnimationType["SLIDE_IN_RIGHT"] = "slideInRight";
    AnimationType["SLIDE_IN_UP"] = "slideInUp";
    AnimationType["SWING"] = "swing";
    AnimationType["ZOOM_IN"] = "zoomIn";
})(AnimationType || (AnimationType = {}));
var OutAnimationType;
(function (OutAnimationType) {
    OutAnimationType["FADE_OUT"] = "fadeOut";
    OutAnimationType["SLIDE_OUT_LEFT"] = "slideOutLeft";
    OutAnimationType["SLIDE_OUT_RIGHT"] = "slideOutRight";
    OutAnimationType["SLIDE_OUT_UP"] = "slideOutUp";
    OutAnimationType["ZOOM_OUT"] = "zoomOut";
})(OutAnimationType || (OutAnimationType = {}));
var PopupType;
(function (PopupType) {
    PopupType["WARNING"] = "warning";
    PopupType["INFO"] = "info";
    PopupType["DANGER"] = "danger";
    PopupType["SUCCESS"] = "success";
})(PopupType || (PopupType = {}));

var ToastPosition;
(function (ToastPosition) {
    ToastPosition["TOP_RIGHT"] = "top-right";
    ToastPosition["TOP_LEFT"] = "top-left";
    ToastPosition["TOP_CENTER"] = "top-center";
    ToastPosition["BOTTOM_RIGHT"] = "bottom-right";
    ToastPosition["BOTTOM_CENTER"] = "bottom-center";
    ToastPosition["BOTTOM_LEFT"] = "bottom-left";
})(ToastPosition || (ToastPosition = {}));
const DefaultToastPosition = ToastPosition.BOTTOM_RIGHT;

const defaultValues = {
    showModal: (_component, _options) => null,
    hideModal: () => null,
    showAlert: (_options) => null,
    hideAlert: () => null,
    showOptionDialog: (_options) => null,
    showInputDialog: (_options) => null,
    showToast: (_options) => null,
    hideToast: (_toastId) => null,
};
const PopupContext = createContext(defaultValues);

const usePopup = () => useContext(PopupContext);

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */


function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

const getDateWithoutTime = function (date) {
    return new Date(date.toDateString());
};
class InputValidation {
    static validateDate(input, value) {
        var _a, _b, _c;
        const validation = input.validation;
        if (validation.required) {
            if (!value) {
                return {
                    success: false,
                    message: (_a = validation.required.message) !== null && _a !== void 0 ? _a : this.DEFAULT_ERROR_MESSAGE,
                };
            }
        }
        if (validation.minDate) {
            if (value &&
                new Date(value).getTime() <
                    getDateWithoutTime(validation.minDate.value).getTime()) {
                return {
                    success: false,
                    message: (_b = validation.minDate.message) !== null && _b !== void 0 ? _b : this.DEFAULT_ERROR_MESSAGE,
                };
            }
        }
        if (validation.maxDate) {
            if (value &&
                new Date(value).getTime() >
                    getDateWithoutTime(validation.maxDate.value).getTime()) {
                return {
                    success: false,
                    message: (_c = validation.maxDate.message) !== null && _c !== void 0 ? _c : this.DEFAULT_ERROR_MESSAGE,
                };
            }
        }
        return {
            success: true,
        };
    }
    static validateText(input, value) {
        var _a, _b, _c;
        const validation = input.validation;
        if (validation.required) {
            if (!value) {
                return {
                    success: false,
                    message: (_a = validation.required.message) !== null && _a !== void 0 ? _a : this.DEFAULT_ERROR_MESSAGE,
                };
            }
        }
        if (validation.minLength) {
            if (value !== undefined && value.length < validation.minLength.value) {
                return {
                    success: false,
                    message: (_b = validation.minLength.message) !== null && _b !== void 0 ? _b : this.DEFAULT_ERROR_MESSAGE,
                };
            }
        }
        if (validation.maxLength) {
            if (value !== undefined && value.length > validation.maxLength.value) {
                return {
                    success: false,
                    message: (_c = validation.maxLength.message) !== null && _c !== void 0 ? _c : this.DEFAULT_ERROR_MESSAGE,
                };
            }
        }
        return {
            success: true,
        };
    }
    static validateNumber(input, value) {
        var _a, _b, _c;
        const validation = input.validation;
        if (validation.required) {
            if (!value) {
                return {
                    success: false,
                    message: (_a = validation.required.message) !== null && _a !== void 0 ? _a : this.DEFAULT_ERROR_MESSAGE,
                };
            }
        }
        if (validation.min) {
            if (value === undefined || value < validation.min.value) {
                return {
                    success: false,
                    message: (_b = validation.min.message) !== null && _b !== void 0 ? _b : this.DEFAULT_ERROR_MESSAGE,
                };
            }
        }
        if (validation.max) {
            if (value !== undefined && value > validation.max.value) {
                return {
                    success: false,
                    message: (_c = validation.max.message) !== null && _c !== void 0 ? _c : this.DEFAULT_ERROR_MESSAGE,
                };
            }
        }
        return {
            success: true,
        };
    }
    static validateFile(input, value) {
        var _a;
        const validation = input.validation;
        if (validation.required) {
            if (!value) {
                return {
                    success: false,
                    message: (_a = validation.required.message) !== null && _a !== void 0 ? _a : this.DEFAULT_ERROR_MESSAGE,
                };
            }
        }
        return {
            success: true,
        };
    }
}
InputValidation.DEFAULT_ERROR_MESSAGE = "Invalid Value";

function Footer({ optionsToRender, footerStyle }) {
    return (React.createElement("div", { className: "react-custom-footer", style: Object.assign({}, footerStyle) },
        React.createElement("div", { className: "react-custom-options-container" }, optionsToRender.map((option, index) => {
            var _a;
            return (React.createElement("button", { key: `option${index}`, className: "react-custom-option-button", onClick: option.onClick, style: (_a = option.style) !== null && _a !== void 0 ? _a : undefined }, option.name));
        }))));
}

const closeIcon = (color = '#484848') => React.createElement("svg", { color: color, height: 20, width: 20, "aria-hidden": "true", "data-prefix": "fas", "data-icon": "times", className: "svg-inline--fa fa-times fa-w-11", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 352 512" },
    React.createElement("path", { fill: "currentColor", d: "M242.72 256l100.07-100.07c12.28-12.28 12.28-32.19 0-44.48l-22.24-22.24c-12.28-12.28-32.19-12.28-44.48 0L176 189.28 75.93 89.21c-12.28-12.28-32.19-12.28-44.48 0L9.21 111.45c-12.28 12.28-12.28 32.19 0 44.48L109.28 256 9.21 356.07c-12.28 12.28-12.28 32.19 0 44.48l22.24 22.24c12.28 12.28 32.2 12.28 44.48 0L176 322.72l100.07 100.07c12.28 12.28 32.2 12.28 44.48 0l22.24-22.24c12.28-12.28 12.28-32.19 0-44.48L242.72 256z" }));
const iconIllustrationTypes = {
    warning: React.createElement("svg", { width: 20, xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 512 512" },
        React.createElement("path", { d: "M256 0C115.2 0 0 115.2 0 256s115.2 256 256 256 256-115.2 256-256S396.8 0 256 0zm0 51.2c28.16 0 48.64 23.04 46.08 51.2L281.6 307.2h-51.2l-20.48-204.8c-2.56-28.16 17.92-51.2 46.08-51.2zm0 409.6c-28.16 0-51.2-23.04-51.2-51.2 0-28.16 23.04-51.2 51.2-51.2s51.2 23.04 51.2 51.2c0 28.16-23.04 51.2-51.2 51.2z" })),
    info: React.createElement("svg", { width: 20, xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 450.56 450.56" },
        React.createElement("path", { d: "M225.28 0C101.376 0 0 101.376 0 225.28s101.376 225.28 225.28 225.28 225.28-101.376 225.28-225.28S349.184 0 225.28 0zm23.552 321.024h-48.128V183.296h48.128v137.728zm0-167.424h-48.128v-30.208h48.128V153.6z" })),
    success: React.createElement("svg", { width: 20, xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 477.867 477.867" },
        React.createElement("path", { d: "M238.933 0C106.974 0 0 106.974 0 238.933s106.974 238.933 238.933 238.933 238.933-106.974 238.933-238.933C477.726 107.033 370.834.141 238.933 0zm131.533 165.666L199.799 336.333c-6.665 6.663-17.468 6.663-24.132 0L107.4 268.066c-6.78-6.548-6.968-17.352-.42-24.132 6.548-6.78 17.352-6.968 24.132-.42.142.138.282.277.42.42l56.201 56.201 158.601-158.601c6.78-6.548 17.584-6.36 24.132.419 6.388 6.614 6.388 17.099 0 23.713z" })),
    danger: React.createElement("svg", { width: 20, xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 512 512" },
        React.createElement("path", { d: "M501.362 383.95L320.497 51.474c-29.059-48.921-99.896-48.986-128.994 0L10.647 383.95c-29.706 49.989 6.259 113.291 64.482 113.291h361.736c58.174 0 94.203-63.251 64.497-113.291zM256 437.241c-16.538 0-30-13.462-30-30s13.462-30 30-30 30 13.462 30 30-13.462 30-30 30zm30-120c0 16.538-13.462 30-30 30s-30-13.462-30-30v-150c0-16.538 13.462-30 30-30s30 13.462 30 30v150z" }))
};

const Header = ({ showCloseButton, type, hideModal, title, headerTextStyle, headerStyle, customIcon, }) => {
    return (React.createElement("div", { className: `react-custom-header react-custom-header-${type}`, style: Object.assign({}, headerStyle) },
        customIcon ? customIcon() : iconIllustrationTypes[type],
        showCloseButton && (React.createElement("div", { style: { position: "absolute", right: 20, cursor: "pointer" }, onClick: hideModal }, closeIcon())),
        React.createElement("div", { className: `react-custom-title ${iconIllustrationTypes[type] ? "react-custom-title-margin" : ""}`, style: Object.assign({}, headerTextStyle) }, title)));
};

function ImageInput({ setInputValues, inputValues, item, error, errorMessageStyle, }) {
    const inputRef = useRef(null);
    const readImage = (event) => {
        if (event.target.files) {
            let imagePromises = [];
            let images = [];
            Array.from(event.target.files).forEach((file) => {
                imagePromises.push(new Promise((resolve) => {
                    var reader = new FileReader();
                    reader.onload = function (e) {
                        images.push({ src: e.target.result, value: file });
                        resolve();
                    };
                    reader.readAsDataURL(file);
                }));
            });
            Promise.all(imagePromises).then(() => {
                setInputValues(Object.assign(Object.assign({}, inputValues), { 
                    // @ts-ignore
                    [item.name]: [...images] }));
                inputRef.current.value = "";
                // event.target.reset();
            });
        }
    };
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { style: { textAlign: "left" } },
            React.createElement("label", { style: { display: "block", marginBottom: 5 } }, item.label || ""),
            React.createElement("div", { style: { cursor: "pointer" }, className: "react-custom-input-item select-image", onClick: () => {
                    if (inputRef.current)
                        inputRef.current.click();
                } }, "Select Image"),
            React.createElement("input", { ref: (ref) => {
                    // @ts-ignore
                    inputRef.current = ref;
                }, value: inputRef.current ? inputRef.current.value : "", multiple: item.multiple || false, className: "react-custom-input-item", onChange: (val) => readImage(val), style: { display: "none" }, id: "image", type: "file" })),
        React.createElement("div", { style: { textAlign: "left" } }, inputValues &&
            inputValues[item.name] &&
            // @ts-ignore
            inputValues[item.name].map((image, index) => (React.createElement("div", { className: "react-custom-input-img-container", key: "image" + index, style: {
                    position: "relative",
                } },
                React.createElement("img", { alt: "", style: { maxHeight: 100 }, src: image.src }),
                React.createElement("div", { onClick: () => {
                        setInputValues(Object.assign(Object.assign({}, inputValues), { 
                            // @ts-ignore
                            [item.name]: [
                                ...inputValues[item.name].slice(0, index),
                                ...inputValues[item.name].slice(index + 1),
                            ] }));
                    }, style: {
                        borderRadius: 5,
                        position: "absolute",
                        top: 5,
                        right: 5,
                        zIndex: 500,
                        cursor: "pointer",
                    } }, closeIcon("white")))))),
        error && (React.createElement("label", { className: "react-custom-input-error-item", style: errorMessageStyle !== null && errorMessageStyle !== void 0 ? errorMessageStyle : undefined }, error))));
}

function Input({ item, setInputValues, inputValues, error, errorMessageStyle, }) {
    return (React.createElement("div", { style: { textAlign: "left" } },
        React.createElement("label", { style: { display: "block" }, className: "react-custom-input-label-item" }, item.label),
        item.inputType && item.inputType !== "textarea" ? (React.createElement("input", { className: "react-custom-input-item", onChange: (val) => {
                setInputValues(Object.assign(Object.assign({}, inputValues), { 
                    // @ts-ignore
                    [item.name]: val.nativeEvent.target.value }));
            }, 
            // @ts-ignore
            value: inputValues[item.name] ? inputValues[item.name] : "", id: item.name, placeholder: item.placeholder, type: item.inputType || "text" })) : null,
        item.inputType === "textarea" ? (React.createElement("textarea", { onChange: (val) => {
                setInputValues(Object.assign(Object.assign({}, inputValues), { 
                    // @ts-ignore
                    [item.name]: val.nativeEvent.target.value }));
            }, 
            // @ts-ignore
            value: inputValues[item.name] ? inputValues[item.name] : "", className: "react-custom-input-item", id: item.name, placeholder: item.placeholder })) : null,
        error && (React.createElement("label", { className: "react-custom-input-error-item", style: errorMessageStyle !== null && errorMessageStyle !== void 0 ? errorMessageStyle : undefined }, error))));
}

// @ts-ignore
Date.prototype.toDateInputValue = function () {
    var local = new Date(this);
    local.setMinutes(this.getMinutes() - this.getTimezoneOffset());
    return local.toJSON().slice(0, 10);
};
const Dialog = (props) => {
    const { title, text, type, hideModal, onConfirm = null, onCancel = null, isAlert = true, showCloseButton = false, isInput = false, confirmText = "Ok", cancelText = "Cancel", inputs = null, onDismissed = null, input, headerTextStyle, textStyle, containerStyle, headerStyle, footerStyle, bodyComponent, errorMessageStyle, options, customIcon, } = props;
    const getDefaultValues = () => {
        let defaultVals = {};
        if (input && !inputs && input.default) {
            if (input.inputType === "date") {
                // @ts-ignore
                defaultVals[input.name] = input.default.toDateInputValue();
            }
            else {
                defaultVals[input.name] = input.default;
            }
        }
        if (inputs && !input) {
            inputs.forEach((i) => {
                if (i.default) {
                    if (i.inputType === "date") {
                        // @ts-ignore
                        defaultVals[i.name] = i.default.toDateInputValue();
                    }
                    else {
                        defaultVals[i.name] = i.default;
                    }
                }
            });
        }
        return defaultVals;
    };
    const [inputValues, setInputValues] = useState(() => getDefaultValues());
    const [errorValues, setErrorValues] = useState({});
    const validateInputValue = (input) => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        let result;
        if ((_a = input.validation) === null || _a === void 0 ? void 0 : _a.validate) {
            return yield input.validation.validate(inputValues[input.name]);
        }
        else {
            switch (input.inputType) {
                case "text":
                    result = InputValidation.validateText(input, inputValues[input.name]);
                    break;
                case "number":
                    result = InputValidation.validateNumber(input, inputValues[input.name]);
                    break;
                case "date":
                    result = InputValidation.validateDate(input, inputValues[input.name]);
                    break;
                case "file":
                    result = InputValidation.validateFile(input, inputValues[input.name]);
                    break;
                case "image":
                    result = InputValidation.validateFile(input, inputValues[input.name]);
                    break;
                default:
                    result = {
                        success: true,
                        message: "",
                    };
            }
        }
        if (!result.success) {
            return { success: false, [input.name]: result.message };
        }
        throw new Error("Unsupported input type");
    });
    const validateInputs = () => {
        setErrorValues({});
        const allInputsToValidate = [];
        if (input && input.validation) {
            allInputsToValidate.push(input);
        }
        if (inputs) {
            for (const i of inputs) {
                if (i.validation) {
                    allInputsToValidate.push(i);
                }
            }
        }
        let errorsMapping = {};
        allInputsToValidate.forEach((input) => {
            const res = validateInputValue(input);
            if (res !== null) {
                errorsMapping = Object.assign(Object.assign({}, errorsMapping), res);
            }
        });
        return errorsMapping;
    };
    const confirmHandle = () => {
        const errors = validateInputs();
        if (Object.keys(errors).length === 0) {
            hideModal();
            if (onConfirm) {
                onConfirm(inputValues);
            }
            if (onDismissed && isInput)
                onDismissed(inputValues);
        }
        else {
            setErrorValues(errors);
        }
    };
    const cancelHandle = () => {
        hideModal();
        if (onCancel)
            onCancel();
        if (onDismissed && isInput)
            onDismissed(inputValues);
    };
    let optionsToRender = [];
    if (!isAlert)
        if (options) {
            optionsToRender = options.map((option) => {
                return Object.assign(Object.assign({}, option), { onClick: () => {
                        if (option.type === "confirm") {
                            confirmHandle();
                        }
                        else if (option.type === "cancel") {
                            cancelHandle();
                        }
                        else ;
                    } });
            });
        }
        else
            optionsToRender = [
                {
                    name: cancelText,
                    onClick: cancelHandle,
                },
                {
                    name: confirmText,
                    onClick: confirmHandle,
                },
            ];
    else
        optionsToRender = [
            {
                name: confirmText,
                onClick: () => {
                    hideModal();
                    onDismissed && onDismissed();
                },
            },
        ];
    let inputsToRender = [];
    if (isInput) {
        if (!inputs)
            inputsToRender = [input];
        else
            inputsToRender = inputs;
    }
    return (React.createElement("div", { className: "react-custom-dialog-wrapper", style: Object.assign({}, containerStyle) },
        React.createElement(Header, { customIcon: customIcon, headerStyle: headerStyle, headerTextStyle: headerTextStyle, showCloseButton: showCloseButton, type: type, hideModal: hideModal, title: title }),
        bodyComponent || (React.createElement(React.Fragment, null,
            text && text !== "" ? (React.createElement("div", { className: "react-custom-body-text", style: Object.assign({}, textStyle) }, text)) : null,
            isInput && (React.createElement("div", { className: "react-custom-inputs-container" },
                React.createElement(React.Fragment, null, inputsToRender.map((item, index) => (React.createElement("div", { key: `input${index}`, className: "react-custom-input-container" }, item.inputType !== "image" ? (React.createElement(Input, { errorMessageStyle: errorMessageStyle, error: errorValues[item.name], item: item, setInputValues: setInputValues, inputValues: inputValues })) : (React.createElement(ImageInput, { errorMessageStyle: errorMessageStyle, error: errorValues[item.name], item: item, setInputValues: setInputValues, inputValues: inputValues })))))))))),
        React.createElement(Footer, { footerStyle: footerStyle, optionsToRender: optionsToRender })));
};

function Modal({ hideModal, Component, ComponentJSX, componentProps }) {
    const [ModalToRender, setModalToRender] = useState(undefined);
    const [animation, setAnimation] = useState({ in: '', out: '' });
    const { animationType, outAnimationType, allowOutsideClick = true, allowCloseOnEscKey = true } = componentProps;
    let timeout = useRef();
    const hideMe = useCallback(() => {
        setAnimation({ out: `animate__animated animate__${outAnimationType} animate__faster`, in: '' });
    }, [outAnimationType]);
    const showMe = useCallback(() => {
        setAnimation({ out: '', in: `animate__animated animate__${animationType} animate__faster` });
    }, [animationType]);
    useEffect(() => {
        if (ModalToRender && !(Component || ComponentJSX)) {
            hideMe();
        }
        else if (Component || ComponentJSX) {
            showMe();
        }
        return () => {
            timeout.current && clearTimeout(timeout.current);
        };
    }, [Component, ComponentJSX, componentProps]);
    useEffect(() => {
        if (animation.in && (Component || ComponentJSX)) {
            // @ts-ignore
            let c;
            if (Component) {
                c = createElement(Component, Object.assign(Object.assign({}, componentProps), { hideModal: hideModal }));
            }
            setModalToRender(ComponentJSX || c);
        }
        if (animation.out) {
            if (!outAnimationType) {
                setModalToRender(undefined);
            }
            else
                timeout.current = setTimeout(() => {
                    setModalToRender(undefined);
                }, 100);
        }
    }, [animation]);
    useEffect(() => {
        const listenForEsc = ((evt) => {
            if (['Esc', 'Escape'].indexOf(evt.key) !== -1) {
                hideModal();
            }
        });
        if (allowCloseOnEscKey && ModalToRender) {
            window.addEventListener('keydown', listenForEsc);
        }
        return () => {
            window.removeEventListener('keydown', listenForEsc);
        };
    }, [ModalToRender]);
    if (!ModalToRender)
        return null;
    return (React.createElement(ModalWrapper, null,
        React.createElement(ModalBackdrop, { onClick: allowOutsideClick ? hideModal : () => {
            } }),
        React.createElement("div", { className: `${animation.in || animation.out}` }, ModalToRender)));
}
const ModalBackdrop = ({ onClick }) => {
    useEffect(() => {
        document.body.classList.add("react-custom-modal-open");
        return () => {
            document.body.classList.remove("react-custom-modal-open");
        };
    }, []);
    return (React.createElement("div", { onClick: onClick, className: `react-custom-modal-backdrop` }));
};
const ModalWrapper = ({ children }) => (React.createElement("div", { className: "react-custom-modal-wrapper" }, children));

function ToastProgress({ timeout, color }) {
    const [width, setWidth] = useState(1);
    const timer = useRef();
    const progress = useCallback(() => {
        if (width < 100) {
            timer.current = setTimeout(() => {
                setWidth(width + 1);
            }, timeout / 105);
        }
    }, [width, timeout]);
    useEffect(() => {
        progress();
        return () => {
            if (timer.current) {
                clearTimeout(timer.current);
            }
        };
    }, [timeout, width, timer]);
    return (React.createElement("div", { className: 'react-custom-toast-progress', style: { width: `${width}%`, background: color !== null && color !== void 0 ? color : 'gray' } }));
}

function Toast({ toasts, hideToast }) {
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { className: `react-custom-toast-container react-custom-toast-${ToastPosition.BOTTOM_LEFT}` }, toasts &&
            toasts
                .filter((t) => t.position === ToastPosition.BOTTOM_LEFT)
                .map((toast) => (React.createElement(ToastItem, { key: toast.id, toast: toast, hideToast: hideToast })))),
        React.createElement("div", { className: `react-custom-toast-container react-custom-toast-${ToastPosition.BOTTOM_CENTER}` }, toasts &&
            toasts
                .filter((t) => t.position === ToastPosition.BOTTOM_CENTER)
                .map((toast) => (React.createElement(ToastItem, { key: toast.id, toast: toast, hideToast: hideToast })))),
        React.createElement("div", { className: `react-custom-toast-container react-custom-toast-${ToastPosition.BOTTOM_RIGHT}` }, toasts &&
            toasts
                .filter((t) => t.position === ToastPosition.BOTTOM_RIGHT)
                .map((toast) => (React.createElement(ToastItem, { key: toast.id, toast: toast, hideToast: hideToast })))),
        React.createElement("div", { className: `react-custom-toast-container react-custom-toast-${ToastPosition.TOP_LEFT}` }, toasts &&
            toasts
                .filter((t) => t.position === ToastPosition.TOP_LEFT)
                .map((toast) => (React.createElement(ToastItem, { key: toast.id, toast: toast, hideToast: hideToast })))),
        React.createElement("div", { className: `react-custom-toast-container react-custom-toast-${ToastPosition.TOP_RIGHT}` }, toasts &&
            toasts
                .filter((t) => t.position === ToastPosition.TOP_RIGHT)
                .map((toast) => (React.createElement(ToastItem, { key: toast.id, toast: toast, hideToast: hideToast })))),
        React.createElement("div", { className: `react-custom-toast-container react-custom-toast-${ToastPosition.TOP_CENTER}` }, toasts &&
            toasts
                .filter((t) => t.position === ToastPosition.TOP_CENTER)
                .map((toast) => (React.createElement(ToastItem, { key: toast.id, toast: toast, hideToast: hideToast }))))));
}
function ToastItem({ toast, hideToast }) {
    const [toastData, setToast] = useState(null);
    const [animation, setAnimation] = useState({
        in: "",
        out: "",
    });
    let timeout = useRef();
    const hideMe = useCallback(() => {
        const outAnimation = {
            [ToastPosition.TOP_RIGHT]: "slideOutRight",
            [ToastPosition.TOP_CENTER]: "slideOutUp",
            [ToastPosition.TOP_LEFT]: "slideOutLeft",
            [ToastPosition.BOTTOM_RIGHT]: "slideOutRight",
            [ToastPosition.BOTTOM_LEFT]: "slideOutLeft",
            [ToastPosition.BOTTOM_CENTER]: "slideOutDown",
        };
        setAnimation({
            out: `animate__animated animate__${outAnimation[toast.position]} animate__faster`,
            in: "",
        });
    }, [toast.position]);
    const showMe = useCallback(() => {
        const inAnimation = {
            [ToastPosition.TOP_RIGHT]: "slideInRight",
            [ToastPosition.TOP_CENTER]: "slideInDown",
            [ToastPosition.TOP_LEFT]: "slideInLeft",
            [ToastPosition.BOTTOM_RIGHT]: "slideInRight",
            [ToastPosition.BOTTOM_LEFT]: "slideInLeft",
            [ToastPosition.BOTTOM_CENTER]: "slideInUp",
        };
        setAnimation({
            in: `animate__animated animate__${inAnimation[toast.position]} animate__faster`,
            out: "",
        });
    }, [toast.position]);
    useEffect(() => {
        if (toastData && !toast) {
            hideMe();
        }
        else if (toast && !toastData) {
            showMe();
            if (toast.timeoutDuration) {
                timeout.current = setTimeout(hideMe, toast.timeoutDuration);
            }
        }
        return () => {
            timeout.current && clearTimeout(timeout.current);
        };
    }, [toast]);
    useEffect(() => {
        if (animation.in && toast) {
            setToast(toast);
        }
        if (animation.out) {
            if (timeout.current) {
                clearTimeout(timeout.current);
            }
            timeout.current = setTimeout(() => {
                setToast(null);
                hideToast(toast.id);
            }, 250);
        }
    }, [animation]);
    if (!toastData)
        return null;
    return (React.createElement("div", { className: `react-custom-toast-${toastData.type} react-custom-toast ${animation.in} ${animation.out}`, style: Object.assign({}, toast.containerStyle) },
        React.createElement("div", { style: {
                width: "90%",
                display: "flex",
                flexDirection: "row",
                alignItems: "center",
            } }, toast.customComponent || (React.createElement(React.Fragment, null,
            React.createElement("div", null, toast.customIcon
                ? toast.customIcon()
                : iconIllustrationTypes[toastData.type]),
            React.createElement("div", { className: "react-custom-toast-text", style: Object.assign({}, toast.textStyle) }, toastData.text)))),
        React.createElement("div", { className: "close-button", style: { width: "10%", cursor: "pointer" }, onClick: hideMe }, closeIcon()),
        toast.timeoutDuration && toast.showProgress && toastData && (React.createElement(ToastProgress, { color: toast.progressColor, timeout: toast.timeoutDuration }))));
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = ".animate__faster {\n  --animate-duration: 600ms;\n}\n\n.react-custom-open {\n  position: relative;\n  overflow: hidden;\n}\n\n.react-custom-modal-backdrop {\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  z-index: -1;\n  position: fixed;\n  cursor: pointer;\n  background: rgba(0, 0, 0, 0.5);\n}\n\n.react-custom-modal-wrapper {\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  width: 100vw;\n  height: 100vh;\n  z-index: 9999;\n  display: flex;\n  overflow: auto;\n  position: fixed;\n  align-items: center;\n  justify-content: center;\n  /* width */\n  /* Handle */\n}\n.react-custom-modal-wrapper ::-webkit-scrollbar {\n  width: 16px;\n}\n.react-custom-modal-wrapper ::-webkit-scrollbar-thumb {\n  background-color: gray;\n  border: 5px solid transparent;\n  border-radius: 8px;\n  background-clip: padding-box;\n}\n\n.react-custom-dialog-wrapper {\n  min-height: 25%;\n  min-width: 300px;\n  max-width: 90vw;\n  max-height: 90vh;\n  overflow: auto;\n  position: relative;\n  background-color: white;\n  border-radius: 10px;\n  justify-content: space-between;\n  display: flex;\n  flex-direction: column;\n}\n\n.react-custom-title {\n  font-weight: 500;\n  font-size: larger;\n}\n\n.react-custom-title-margin {\n  margin-left: 10px;\n}\n\n.react-custom-body-text {\n  font-size: medium;\n  text-align: left;\n  padding: 20px;\n}\n\n.react-custom-header {\n  padding: 15px 20px;\n  text-align: left;\n  flex-direction: row;\n  display: flex;\n  align-items: center;\n}\n\n.react-custom-toast-container {\n  position: fixed;\n  z-index: 9999;\n}\n\n.react-custom-toast-progress {\n  padding: 0 !important;\n  margin: 0 !important;\n  position: fixed;\n  bottom: 0;\n  border-radius: 5px;\n  overflow: hidden;\n  height: 2px;\n  left: 0;\n  right: 0;\n  transition: 100ms ease-in-out;\n}\n\n.react-custom-toast {\n  min-width: 10vw;\n  max-width: 20vw;\n  padding: 20px;\n  border-radius: 5px;\n  display: flex;\n  flex-direction: row;\n  align-items: center;\n  box-shadow: rgba(0, 0, 0, 0.4588235294) 0px 0px 5px 0px;\n  margin-top: 10px;\n  overflow: auto;\n}\n@media only screen and (max-width: 600px) {\n  .react-custom-toast {\n    max-width: 80vw;\n  }\n}\n\n.react-custom-toast-bottom-right {\n  right: 10px;\n  bottom: 10px;\n}\n\n.react-custom-toast-bottom-left {\n  left: 10px;\n  bottom: 10px;\n}\n\n.react-custom-toast-top-right {\n  top: 10px;\n  right: 10px;\n}\n\n.react-custom-toast-top-left {\n  top: 10px;\n  left: 10px;\n}\n\n.react-custom-toast-top-center {\n  top: 10px;\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  left: 0;\n  right: 0;\n  margin: 0 auto;\n  width: fit-content;\n}\n\n.react-custom-toast-bottom-center {\n  bottom: 10px;\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  left: 0;\n  right: 0;\n  margin: 0 auto;\n  width: fit-content;\n}\n\n.react-custom-toast-text {\n  margin-left: 10px;\n}\n\n.react-custom-header-info,\n.react-custom-toast-info {\n  background-color: lightblue;\n}\n\n.react-custom-header-success,\n.react-custom-toast-success {\n  background-color: lightgreen;\n}\n\n.react-custom-header-warning,\n.react-custom-toast-warning {\n  background-color: orange;\n}\n\n.react-custom-header-danger,\n.react-custom-toast-danger {\n  background-color: coral;\n}\n\n.react-custom-footer {\n  padding: 20px;\n  text-align: right;\n}\n\n.react-custom-options-container {\n  display: flex;\n  flex-flow: row wrap;\n  flex-direction: row;\n}\n\n.react-custom-option-button {\n  border-radius: 5px;\n  border: none;\n  padding: 10px 20px;\n  margin: 5px;\n  flex: 1;\n  overflow: hidden;\n  background-color: white;\n  box-shadow: rgba(0, 0, 0, 0.4588235294) 0px 0px 5px 0px;\n  cursor: pointer;\n}\n\n.react-custom-option-button:hover {\n  background-color: whitesmoke;\n}\n\n.react-custom-inputs-container {\n  padding: 20px;\n}\n\n.react-custom-input-container {\n  padding-bottom: 20px;\n}\n\n.react-custom-input-item {\n  padding: 10px;\n  border: 1px solid gainsboro;\n  border-radius: 5px;\n  overflow: hidden;\n  width: 100%;\n  box-sizing: border-box;\n  -moz-box-sizing: border-box;\n  -webkit-box-sizing: border-box;\n}\n\n.react-custom-input-error-item {\n  padding-top: 10px;\n  padding-bottom: 10px;\n  padding-left: 5px;\n  color: darkred;\n  font-size: 15px;\n  display: block;\n}\n\n.react-custom-input-label-item {\n  padding-top: 10px;\n  padding-bottom: 10px;\n  padding-left: 5px;\n}\n\n.select-image:hover {\n  background: #e3e3e3;\n}\n\n.react-custom-input-img-container {\n  padding: 5px;\n  display: flex;\n  width: 100%;\n  box-sizing: border-box;\n  -moz-box-sizing: border-box;\n  -webkit-box-sizing: border-box;\n  position: relative;\n  justify-content: center;\n  align-items: center;\n  margin-top: 10px;\n  border-radius: 5px;\n  background: #d0d0d0;\n}\n\n.react-custom-input-item:focus {\n  outline: none;\n  border: 1px solid lightblue;\n}";
styleInject(css_248z);

const PopupRoot = () => {
    let { componentJSX: ComponentJSX, component: Component, toasts, componentProps, hideModal, hideToast, } = usePopup();
    componentProps = Object.assign({}, componentProps);
    return (React.createElement(React.Fragment, null,
        React.createElement(Modal, { componentProps: componentProps, Component: Component, ComponentJSX: ComponentJSX, hideModal: hideModal }),
        React.createElement(Toast, { hideToast: hideToast, toasts: toasts })));
};

const PopupReducer = (state, { type, component, componentProps, componentJSX, toast, id, }) => {
    switch (type) {
        case "openModal":
            return Object.assign(Object.assign({}, state), { component, componentProps, componentJSX });
        case "hideModal":
            return Object.assign(Object.assign({}, state), { component: null, modalProps: {}, componentJSX: null });
        case "showToast":
            return Object.assign(Object.assign({}, state), { toasts: [...state.toasts, toast], componentProps });
        case "hideToast":
            const index = state.toasts.findIndex((t) => t.id === id);
            return Object.assign(Object.assign({}, state), { toasts: [
                    ...state.toasts.slice(0, index),
                    ...state.toasts.slice(index + 1),
                ] });
        default:
            throw new Error("Unspecified reducer action");
    }
};
let DefaultPopupActions = {
    showModal: (_component, _options) => null,
    hideModal: () => null,
    showAlert: (_options) => null,
    hideAlert: () => null,
    showOptionDialog: (_options) => null,
    showInputDialog: (_options) => null,
    showToast: (_options) => null,
    hideToast: (_toastId) => null,
};
Object.assign({}, DefaultPopupActions);

const PopupProvider = ({ children }) => {
    const initialState = {
        componentJSX: undefined,
        component: undefined,
        componentProps: {},
        toasts: [],
        showModal: (componentJSX, options) => {
            dispatch({
                type: "openModal",
                componentJSX,
                componentProps: Object.assign({}, options),
            });
        },
        hideModal: () => {
            dispatch({ type: "hideModal" });
        },
        showAlert: (options) => {
            dispatch({
                type: "openModal",
                component: Dialog,
                componentProps: Object.assign({ isAlert: true, isInputDialog: false }, options),
            });
        },
        hideAlert: () => {
            dispatch({ type: "hideModal" });
        },
        showOptionDialog: (options) => {
            dispatch({
                type: "openModal",
                component: Dialog,
                componentProps: Object.assign({ isAlert: false, isInput: false }, options),
            });
        },
        showInputDialog: (options) => {
            dispatch({
                type: "openModal",
                component: Dialog,
                componentProps: Object.assign({ isAlert: false, isInput: true }, options),
            });
        },
        showToast: (options) => {
            dispatch({
                type: "showToast",
                toast: Object.assign(Object.assign({}, options), { position: options.position || DefaultToastPosition, id: Math.random().toString(36).substring(7) }),
                componentProps: Object.assign({}, options),
            });
        },
        hideToast: (toastId) => {
            dispatch({
                type: "hideToast",
                id: toastId,
            });
        },
    };
    const [state, dispatch] = useReducer(PopupReducer, initialState);
    return (React.createElement("div", null,
        React.createElement(PopupContext.Provider, { value: state },
            React.createElement(PopupRoot, null),
            children)));
};

export { AnimationType, DefaultToastPosition, OutAnimationType, PopupProvider, PopupType, ToastPosition, usePopup };
//# sourceMappingURL=index.es.js.map
